@@ -6,7 +6,7 @@ use Pcore::HTTP qw[http_get];
 
 has max_threads => ( is => 'ro', isa => PositiveInt, default => 1 );
 has anticaptcha_key => ( is => 'ro', isa => Str );
-has cookie_jar => ( is => 'ro', isa => HashRef, default => sub { {} } );
+has cookies => ( is => 'ro', isa => HashRef, default => sub { {} } );
 
 has _anticaptcha => ( is => 'lazy', isa => Maybe [ InstanceOf ['Pcore::API::AntiCaptcha'] ], init_arg => undef );
 has _threads => ( is => 'ro', isa => PositiveOrZeroInt, default => 0, init_arg => undef );
@@ -73,10 +73,10 @@ sub _request ( $self, $url, $cb ) {
 
     http_get(
         $url,
-        timeout    => $HTTP_TIMEOUT,
-        useragent  => $HTTP_USERAGENT,
-        cookie_jar => $self->{cookie_jar},
-        on_finish  => sub ($res) {
+        timeout   => $HTTP_TIMEOUT,
+        useragent => $HTTP_USERAGENT,
+        cookies   => $self->{cookies},
+        on_finish => sub ($res) {
             if ( $res->status == 503 ) {    # captcha
                 if ( !$self->_anticaptcha ) {
                     $on_finish->($res);
@@ -141,10 +141,10 @@ sub _resolve_captcha ( $self, $url, $res, $cb ) {
     # get captcha image
     http_get(
         $image_url,
-        timeout    => $HTTP_TIMEOUT,
-        useragent  => $HTTP_USERAGENT,
-        cookie_jar => $self->{cookie_jar},
-        on_finish  => sub ($img_res) {
+        timeout   => $HTTP_TIMEOUT,
+        useragent => $HTTP_USERAGENT,
+        cookies   => $self->{cookies},
+        on_finish => sub ($img_res) {
 
             # resolve captcha
           RESOLVE_CAPTCHA:
@@ -169,10 +169,10 @@ sub _resolve_captcha ( $self, $url, $res, $cb ) {
 
                     http_get(
                         P->uri( '/sorry/CaptchaRedirect?' . $query, base => $base_url ),
-                        timeout    => $HTTP_TIMEOUT,
-                        useragent  => $HTTP_USERAGENT,
-                        cookie_jar => $self->{cookie_jar},
-                        on_finish  => sub ($res) {
+                        timeout   => $HTTP_TIMEOUT,
+                        useragent => $HTTP_USERAGENT,
+                        cookies   => $self->{cookies},
+                        on_finish => sub ($res) {
 
                             # captcha recognized incorrectly
                             if ( $res->status == 503 ) {
